import { useEffect, useRef } from 'react';

function useEventListener(eventName, handler, el) {
  var element = useRef();
  var savedHandler = useRef();
  useEffect(function () {
    savedHandler.current = handler;
  }, [handler]);
  useEffect(function () {
    if (typeof window === 'undefined') return;
    element.current = el || window; // Make sure element supports addEventListener

    var isSupported = element && element.addEventListener;
    if (!isSupported) return; // Create event listener that calls handler function stored in ref

    var eventListener = function eventListener(event) {
      return savedHandler.current(event);
    }; // Add event listener


    element.addEventListener(eventName, eventListener); // Remove event listener on cleanup

    return function () {
      element.removeEventListener(eventName, eventListener);
    };
  }, [eventName, el] // Re-run if eventName or element changes
  );
}

export default useEventListener;